==> jc-1.4.0.tar.gz: soot/util/IterableMap__242.h <==
// class soot.util.IterableMap$2

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class ca427569b5b2f804 java_util_AbstractSet
// @dep_class e7e5b1df634e6d74 soot_util_IterableMap__242

// header file dependencies
// @dep_header java_util_AbstractSet

#include "java/util/AbstractSet.h"

#ifndef _JC_soot_util_IterableMap__242_H_
#define _JC_soot_util_IterableMap__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;
struct _jc_soot_util_IterableMap$object;

// Typedefs
typedef struct _jc_soot_util_IterableMap__242$sub_refs	_jc_soot_util_IterableMap__242$sub_refs;
typedef struct _jc_soot_util_IterableMap__242$sub_nonrefs	_jc_soot_util_IterableMap__242$sub_nonrefs;
typedef struct _jc_soot_util_IterableMap__242$refs	_jc_soot_util_IterableMap__242$refs;
typedef struct _jc_soot_util_IterableMap__242$nonrefs	_jc_soot_util_IterableMap__242$nonrefs;
typedef struct _jc_soot_util_IterableMap__242$object	_jc_soot_util_IterableMap__242$object;

typedef const struct _jc_soot_util_IterableMap__242$vmethods	_jc_soot_util_IterableMap__242$vmethods;
typedef const struct _jc_soot_util_IterableMap__242$vtable	_jc_soot_util_IterableMap__242$vtable;
typedef const struct _jc_soot_util_IterableMap__242$vtype	_jc_soot_util_IterableMap__242$vtype;

// Constructors
extern void _jc_soot_util_IterableMap__242$method$_init$3b42266daebac21c(_jc_env *, struct _jc_soot_util_IterableMap__242$object *, struct _jc_soot_util_IterableMap$object *);

// Virtual methods
extern void _jc_soot_util_IterableMap__242$method$clear$0a5acde3ee27a066(_jc_env *, struct _jc_soot_util_IterableMap__242$object *);
extern jboolean _jc_soot_util_IterableMap__242$method$contains$d3bd70da40f05cb1(_jc_env *, struct _jc_soot_util_IterableMap__242$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_soot_util_IterableMap__242$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_soot_util_IterableMap__242$object *);
extern jboolean _jc_soot_util_IterableMap__242$method$remove$d21babbbb7fafe72(_jc_env *, struct _jc_soot_util_IterableMap__242$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_soot_util_IterableMap__242$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_util_IterableMap__242$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_IterableMap__242$method_info$clear$0a5acde3ee27a066;
extern _jc_method _jc_soot_util_IterableMap__242$method_info$contains$d3bd70da40f05cb1;
extern _jc_method _jc_soot_util_IterableMap__242$method_info$iterator$3cc91493d50f531c;
extern _jc_method _jc_soot_util_IterableMap__242$method_info$remove$d21babbbb7fafe72;
extern _jc_method _jc_soot_util_IterableMap__242$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_soot_util_IterableMap__242$vmethods {
	void	(*clear$0a5acde3ee27a066)(_jc_env *, struct _jc_soot_util_IterableMap__242$object *);
	jboolean	(*contains$d3bd70da40f05cb1)(_jc_env *, struct _jc_soot_util_IterableMap__242$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_soot_util_IterableMap__242$object *);
	jboolean	(*remove$d21babbbb7fafe72)(_jc_env *, struct _jc_soot_util_IterableMap__242$object *, struct _jc_java_lang_Object$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_util_IterableMap__242$object *);
};

// Vtable
struct _jc_soot_util_IterableMap__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractSet$vmethods	java_util_AbstractSet;
	_jc_soot_util_IterableMap__242$vmethods	soot_util_IterableMap__242;
};

// Vtype
struct _jc_soot_util_IterableMap__242$vtype {
	_jc_type			type;
	_jc_soot_util_IterableMap__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_IterableMap__242$sub_refs {
	struct _jc_soot_util_IterableMap$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_util_IterableMap__242$refs {
    _jc_soot_util_IterableMap__242$sub_refs	soot_util_IterableMap__242;
    _jc_java_util_AbstractSet$sub_refs	java_util_AbstractSet;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_IterableMap__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_IterableMap__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractSet$sub_nonrefs	java_util_AbstractSet;
    _jc_soot_util_IterableMap__242$sub_nonrefs	soot_util_IterableMap__242;
};

// Object instance structure
struct _jc_soot_util_IterableMap__242$object {
	_jc_soot_util_IterableMap__242$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_IterableMap__242$vtype	*vtype;
	_jc_soot_util_IterableMap__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_IterableMap__242$vtype _jc_soot_util_IterableMap__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_IterableMap__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_IterableMap__242$class_object;

#endif	/* _JC_soot_util_IterableMap__242_H_ */

==> jc-1.4.6.tar.gz: soot/util/IterableMap__242.h <==
// class soot.util.IterableMap$2

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class ca427569b5b2f804 java_util_AbstractSet
// @dep_class e7e5b1df634e6d74 soot_util_IterableMap__242

// header file dependencies
// @dep_header java_util_AbstractSet

#include "java/util/AbstractSet.h"

#ifndef _JC_soot_util_IterableMap__242_H_
#define _JC_soot_util_IterableMap__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;
struct _jc_soot_util_IterableMap$object;

// Typedefs
typedef struct _jc_soot_util_IterableMap__242$sub_refs	_jc_soot_util_IterableMap__242$sub_refs;
typedef struct _jc_soot_util_IterableMap__242$sub_nonrefs	_jc_soot_util_IterableMap__242$sub_nonrefs;
typedef struct _jc_soot_util_IterableMap__242$refs	_jc_soot_util_IterableMap__242$refs;
typedef struct _jc_soot_util_IterableMap__242$nonrefs	_jc_soot_util_IterableMap__242$nonrefs;
typedef struct _jc_soot_util_IterableMap__242$object	_jc_soot_util_IterableMap__242$object;

typedef const struct _jc_soot_util_IterableMap__242$vmethods	_jc_soot_util_IterableMap__242$vmethods;
typedef const struct _jc_soot_util_IterableMap__242$vtable	_jc_soot_util_IterableMap__242$vtable;
typedef const struct _jc_soot_util_IterableMap__242$vtype	_jc_soot_util_IterableMap__242$vtype;

// Constructors
extern void _jc_soot_util_IterableMap__242$method$_init$3b42266daebac21c(_jc_env *, struct _jc_soot_util_IterableMap__242$object *, struct _jc_soot_util_IterableMap$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_util_IterableMap__242$method$clear$0a5acde3ee27a066(_jc_env *, struct _jc_soot_util_IterableMap__242$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_util_IterableMap__242$method$contains$d3bd70da40f05cb1(_jc_env *, struct _jc_soot_util_IterableMap__242$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_util_IterableMap__242$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_soot_util_IterableMap__242$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_util_IterableMap__242$method$remove$d21babbbb7fafe72(_jc_env *, struct _jc_soot_util_IterableMap__242$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_util_IterableMap__242$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_util_IterableMap__242$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_IterableMap__242$method_info$clear$0a5acde3ee27a066;
extern _jc_method _jc_soot_util_IterableMap__242$method_info$contains$d3bd70da40f05cb1;
extern _jc_method _jc_soot_util_IterableMap__242$method_info$iterator$3cc91493d50f531c;
extern _jc_method _jc_soot_util_IterableMap__242$method_info$remove$d21babbbb7fafe72;
extern _jc_method _jc_soot_util_IterableMap__242$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_soot_util_IterableMap__242$vmethods {
	void	(*clear$0a5acde3ee27a066)(_jc_env *, struct _jc_soot_util_IterableMap__242$object *) _JC_JCNI_ATTR;
	jboolean	(*contains$d3bd70da40f05cb1)(_jc_env *, struct _jc_soot_util_IterableMap__242$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_soot_util_IterableMap__242$object *) _JC_JCNI_ATTR;
	jboolean	(*remove$d21babbbb7fafe72)(_jc_env *, struct _jc_soot_util_IterableMap__242$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_util_IterableMap__242$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_IterableMap__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractSet$vmethods	java_util_AbstractSet;
	_jc_soot_util_IterableMap__242$vmethods	soot_util_IterableMap__242;
};

// Vtype
struct _jc_soot_util_IterableMap__242$vtype {
	_jc_type			type;
	_jc_soot_util_IterableMap__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_IterableMap__242$sub_refs {
	struct _jc_soot_util_IterableMap$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_util_IterableMap__242$refs {
    _jc_soot_util_IterableMap__242$sub_refs	soot_util_IterableMap__242;
    _jc_java_util_AbstractSet$sub_refs	java_util_AbstractSet;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_IterableMap__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_IterableMap__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractSet$sub_nonrefs	java_util_AbstractSet;
    _jc_soot_util_IterableMap__242$sub_nonrefs	soot_util_IterableMap__242;
};

// Object instance structure
struct _jc_soot_util_IterableMap__242$object {
	_jc_soot_util_IterableMap__242$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_IterableMap__242$vtype	*vtype;
	_jc_soot_util_IterableMap__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_IterableMap__242$vtype _jc_soot_util_IterableMap__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_IterableMap__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_IterableMap__242$class_object;

#endif	/* _JC_soot_util_IterableMap__242_H_ */
